@@ -44,6 +44,7 @@ import email
 import errno
 import fcntl
 import hashlib
+import encodings.utf_8
 import hubzero.config.webconfig
 import mailproc
 import MySQLdb
@@ -106,7 +107,7 @@ try:
 		### hash the subject and message to attempt to detect duplicate submissions and prevent email loops
 		hubhashdir = '/var/log/exim4/hubmailedhash/'
 		m = hashlib.md5()
-		m.update(emailbody + emailsubject + emailFromAddress)
+		m.update((emailbody + emailsubject + emailFromAddress).encode('utf-8'))
 		mailhash =  m.hexdigest()
 
 		if not os.path.exists(hubhashdir):
@@ -132,7 +133,7 @@ try:
 			mailproc.log("Email loop detected on subject/body/from hash (" + mailhash + ")")
 			mailproc.log("Cancelling processing")
 			exit(1)
-		else:	
+		else:
 			with open(hashfilename, "w") as f:
 				f.write("")
 
@@ -175,14 +176,13 @@ try:
 
 			# Lookup this jos_forum_posts record contained in the token
 			mailproc.log("Looking up forum info for forum_post_id = " + str(forum_post_id))
-			db = mailproc.db_connect()
-			
+
 			# have to support multiple database schemas for this query
 			db = mailproc.db_connect()
 			cursor = db.cursor()
 			sql = "SELECT count(1) FROM information_schema.COLUMNS WHERE TABLE_NAME = 'jos_forum_posts' AND COLUMN_NAME = 'scope'"
 			cursor.execute(sql)
-			rs = cursor.fetchone()			
+			rs = cursor.fetchone()
 
 			# newer table version requires different lookups
 			if rs[0] == 1:
@@ -197,7 +197,7 @@ try:
 				sql  = "SELECT jfp.`id`, jfp.`parent`, jfp.`group_id`, jfp.`category_id`, jfp.`title`, 0 ,0"
 				sql += "FROM jos_forum_posts jfp "
 				sql += "WHERE jfp.id = %s "
-				
+
 			data = (forum_post_id)
 			cursor.execute(sql, data)
 
@@ -221,9 +221,36 @@ try:
 				mailproc.log("Forum category is closed, not posting")
 				exit(0)
 
+			access = 4
+			state = 1
+
+			# If a parent is set...
+			if parent != 0 :
+				# Lookup the parent record
+				mailproc.log("Looking up forum info for parent forum_post_id = " + str(parent))
+
+				db = mailproc.db_connect()
+				cursor = db.cursor()
+				sql  = "SELECT jfp.`access`, jfp.`state` "
+				sql += "FROM jos_forum_posts jfp "
+				sql += "WHERE jfp.id = %s "
+
+				data = (parent)
+				cursor.execute(sql, data)
+
+				rs = cursor.fetchone()
+
+				if not rs:
+					raise Exception("Cannot obtain info for parent jos_forum_post with ID " + str(parent))
+				else:
+					access = rs[0]
+					state = rs[1]
+
+				cursor.close()
+				db.close()
 
 			# Look up group name
-			mailproc.log("Looking up group informaiton on forum post for groupid " + str(groupid))
+			mailproc.log("Looking up group information on forum post for groupid " + str(groupid))
 			db = mailproc.db_connect()
 			cursor = db.cursor()
 			sql  = "SELECT xg.`description`, xg.`cn`, case when plugins like '%%forum=nobody%%' then 1 else 0 end as ForumClosed FROM jos_xgroups xg WHERE xg.gidNumber = %s"
@@ -253,17 +280,17 @@ try:
 			sql = "SELECT count(1) FROM information_schema.COLUMNS WHERE TABLE_NAME = 'jos_forum_posts' AND COLUMN_NAME = 'scope'"
 			cursor.execute(sql)
 			rs = cursor.fetchone()
-			if rs[0] == 1: 
-				scope_field = True 
-			else: 
+			if rs[0] == 1:
+				scope_field = True
+			else:
 				scope_field = False
 
 			sql = "SELECT count(1) FROM information_schema.COLUMNS WHERE TABLE_NAME = 'jos_forum_posts' AND COLUMN_NAME = 'thread'"
 			cursor.execute(sql)
 			rs = cursor.fetchone()
-			if rs[0] == 1: 
-				thread_field = True 
-			else: 
+			if rs[0] == 1:
+				thread_field = True
+			else:
 				thread_field = False
 
 			db = mailproc.db_connect()
@@ -273,7 +300,7 @@ try:
 			data = ("Emailed forum response from " + emailFromAddress,
 				userfeedback + "\n---- Emailed forum response from " + emailFromAddress,
 				mailproc.getCurrentTime(), userid, 1, 0,
-				parent, 0, 4,
+				parent, 0, access,
 				0, mailproc.getCurrentTime(), userid, categoryid,
 				mailproc.getCurrentTime())
 
@@ -305,10 +332,10 @@ try:
 			db = mailproc.db_connect()
 			cursor = db.cursor ()
 
-			sql = "select u.id, u.email "
-			sql += "from jos_xgroups_members m "
-			sql += "join jos_users u on (u.id = m.uidNumber) "
-			sql += "join jos_xgroups_memberoption mo on (mo.gidNumber = m.gidNumber and mo.userID = u.id and mo.optionname = 'receive-forum-email') "
+			sql  = "SELECT u.id, u.email "
+			sql += "FROM jos_xgroups_members m "
+			sql += "JOIN jos_users u ON (u.id = m.uidNumber) "
+			sql += "JOIN jos_xgroups_memberoption mo ON (mo.gidNumber = m.gidNumber and mo.userID = u.id and mo.optionname = 'receive-forum-email') "
 			sql += "where m.gidNumber = %s and mo.optionvalue = 1 "
 			data = (groupid)
 			cursor.execute(sql, data)
@@ -329,7 +356,7 @@ try:
 				addUnsubscribeSection = False
 
 			forumlink = mailproc.hubLongURL + "/groups/" + groupName + "/forum/" + postsection + "/" + postcategory + "/" + str(parent) + "#c" + str(newCommentID)
-				
+
 			## Loop through all people who want email notifications of forum posts
 			for row in rows:
 				mailproc.log('Sending response email to ' + row[1])
@@ -369,5 +396,3 @@ except Exception, ex:
 	exit(1)
 finally:
 	mailproc.closelog()
-
-
